//=========================================================
//Description : USB Seriel product demo program for Delphi
//DLL Version : USBDII.dll V 2.0.0.1
//Release Date : 2009/09/01
//Author : Samuel Tseng
//
//Copyright 2009 Decision Computer
//All Right Reserved
//=========================================================

unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls;

type
  TForm1 = class(TForm)
    Memo1: TMemo;
    Button1: TButton;
    Button2: TButton;
    Button3: TButton;
    Button4: TButton;
    cbType: TComboBox;
    cbID: TComboBox;
    Button5: TButton;
    Button6: TButton;
    Button7: TButton;
    Button8: TButton;
    RadioButton1: TRadioButton;
    RadioButton2: TRadioButton;
    Panel1: TPanel;
    cbCom: TComboBox;
    Timer1: TTimer;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
    procedure Button5Click(Sender: TObject);
    procedure Button4Click(Sender: TObject);
    procedure Button3Click(Sender: TObject);
    procedure Button6Click(Sender: TObject);
    procedure Button7Click(Sender: TObject);
    procedure Button8Click(Sender: TObject);
    procedure RadioButton1Click(Sender: TObject);
    procedure RadioButton2Click(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
  private
    { Private declarations }
    function MatchType(index:integer):integer;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

  Mode : boolean; // true for USB ; false for Serial

  Is8PR,IsLABKIT : boolean;

  DllHandle : THandle;
  hDevice : THandle;

  hid_OpenDevice : function( card_type : integer ; card_number : integer ) : THandle WINAPI;
  hid_Closedevice : function ( HUSB : longint ): bool WINAPI;
  hid_GetDigitalByte : function( hUSB : THandle ; address : integer ; data : Pointer ) : bool WINAPI;
  hid_SetDigitalByte : function( hUSB : THandle ; address : longint ; data : byte) : bool WINAPI;
  hid_GetAnalogChannel : function(hUSB : THandle ; address : integer ; data : Pointer) : bool WINAPI;

  com_OpenDevice : function( card_type : integer ; card_number : integer ; com_number : integer) : THandle WINAPI;
  com_CloseDevice : function ( hCom : THandle ): bool WINAPI;
  com_GetDigitalByte : function( hCom : THandle ; address : integer ; data : Pointer ) : bool WINAPI;
  com_SetDigitalByte : function( hCom : THandle ; address : longint ; data : byte) : bool WINAPI;

implementation

{$R *.dfm}

procedure TForm1.FormCreate(Sender: TObject);
begin

  // load 'USBDII.DLL'

  DllHandle := LoadLibrary('USBDII.DLL');

  hid_OpenDevice := GetProcAddress(DllHandle,'_hid_OpenDevice@8');
  hid_CloseDevice := GetProcAddress(DllHandle,'_hid_CloseDevice@4');
  hid_GetDigitalByte := GetProcAddress(DllHandle,'_hid_GetDigitalByte@12');
  hid_SetDigitalByte := GetProcAddress(DllHandle,'_hid_SetDigitalByte@12');
  hid_GetAnalogChannel := GetProcAddress(DllHandle,'_hid_GetAnalogChannel@12');

  com_OpenDevice := GetProcAddress(DllHandle,'_com_OpenDevice@12');
  com_CloseDevice := GetProcAddress(DllHandle,'_com_CloseDevice@4');
  com_GetDigitalByte := GetProcAddress(DllHandle,'_com_GetDigitalByte@12');
  com_SetDigitalByte := GetProcAddress(DllHandle,'_com_SetDigitalByte@12');

  // initialized params

  hDevice := INVALID_HANDLE_VALUE;

  Mode := true;
  memo1.Clear;


end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  // free dll
  FreeLibrary(DllHandle);
end;


procedure TForm1.Button1Click(Sender: TObject);
begin

  if Mode then hDevice := hid_OpenDevice(MatchType(cbType.ItemIndex), cbID.ItemIndex)
  else
    hDevice := com_OpenDevice(MatchType(cbType.ItemIndex), cbID.ItemIndex, cbCom.ItemIndex+1);

  If hDevice = INVALID_HANDLE_VALUE Then    //Fail to Get Device Address
  begin
    memo1.Lines.Add('Fail to Get Device Address');
  end else  //Open Device Success
  begin
    memo1.Lines.Add('Open Device Success');
    memo1.Lines.Add('handle = '+InttoStr(hDevice));

    if not Mode then Timer1.Enabled := true;  

    Button1.Enabled := false;

  end;

  if isLABKIT then Button7.Enabled := true
  else
    Button7.Enabled := false;

  if is8PR then    Button8.Enabled := true
  else
    Button8.Enabled := false;

end;

procedure TForm1.Button2Click(Sender: TObject);
var
  invalue : byte;
  lResult : boolean;
begin

  if hDevice = INVALID_HANDLE_VALUE then exit;

  if Mode then lResult := hid_GetDigitalByte(hDevice, 0, @invalue)
  else
    lResult := com_GetDigitalByte(hDevice, 0, @invalue);

    
  if lResult then
  begin
    memo1.Lines.Add('Port0 = '+InttoStr(invalue));
  end
  else
    memo1.Lines.Add('read error');

end;

procedure TForm1.Button3Click(Sender: TObject);
var
  outvalue: Integer;
  lResult : boolean;
begin

  outvalue := 1;

  if hDevice = INVALID_HANDLE_VALUE then exit;

  if Mode then lResult := hid_SetDigitalByte(hDevice, 2, outvalue)
  else
    lResult := com_SetDigitalByte(hDevice, 2, outvalue);

  if lResult then
  begin
    memo1.Lines.Add('Port2 = '+InttoStr(outvalue));
  end
  else
    memo1.Lines.Add('write error');

end;

procedure TForm1.Button4Click(Sender: TObject);
begin

  if Mode then hid_CloseDevice(hDevice)
  else
    com_CloseDevice(hDevice);

  hDevice := INVALID_HANDLE_VALUE;
  memo1.Lines.Add('Device close');

  Button1.Enabled := true;  
  Button7.Enabled := true;
  Button8.Enabled := true;

  Timer1.Enabled := false;
  
end;

procedure TForm1.Button5Click(Sender: TObject);
var
  invalue : byte;
  lResult : boolean;
begin

  if hDevice = INVALID_HANDLE_VALUE then exit;

  if Mode then lResult := hid_GetDigitalByte(hDevice, 1, @invalue)
  else
    lResult := com_GetDigitalByte(hDevice, 1, @invalue);

  if lResult then
  begin
    memo1.Lines.Add('Port1 = '+InttoStr(invalue));
  end
  else
    memo1.Lines.Add('read error');

end;

procedure TForm1.Button6Click(Sender: TObject);
var
  outvalue: Integer;
  lResult : boolean;
begin

  outvalue := 3;

  if hDevice = INVALID_HANDLE_VALUE then exit;

  if Mode then lResult := hid_SetDigitalByte(hDevice, 3, outvalue)
  else
    lResult := com_SetDigitalByte(hDevice, 3, outvalue);

  if lResult then
  begin
    memo1.Lines.Add('Port3 = '+InttoStr(outvalue));
  end
  else
   memo1.Lines.Add('write error');

end;

procedure TForm1.Button7Click(Sender: TObject);
var
  I,ADValue : Integer;
begin

  if hDevice = INVALID_HANDLE_VALUE then exit;

  for I := 0 to 7 do
  begin
    hid_GetAnalogChannel(hDevice,I,@ADvalue);
    memo1.Lines.Add('AD #'+InttoStr(I)+' = '+InttoStr(ADvalue));
  end;

end;

procedure TForm1.Button8Click(Sender: TObject);
var
  invalue : byte;
  lResult : boolean;
begin

  if hDevice = INVALID_HANDLE_VALUE then exit;

  if Mode then lResult := hid_GetDigitalByte(hDevice, $10, @invalue)
  else
    lResult := com_GetDigitalByte(hDevice, $10, @invalue);

  if lResult then
  begin
    //inDataTemp := inData And $30;

    if (invalue And $10) = 0 then
    begin
      memo1.Lines.Add('JP10 is close.');
      memo1.Lines.Add('DIO0-DIO7 is for input');
    end else
    begin
      memo1.Lines.Add('JP10 is open');
      memo1.Lines.Add('DIO0-DIO7 is for output');
    end;

    if (invalue And $20) = 0 then
    begin
      memo1.Lines.Add('JP11 is close');
      memo1.Lines.Add('DIO15-DIO8 is for input');
    end else
    begin
      memo1.Lines.Add('JP11 is open');
      memo1.Lines.Add('DIO15-DIO8 is for output');
    end;
  end;
end;

function TForm1.MatchType(index:integer):integer;
begin
{
Card type   type num

USB_16PIO	  0x01
USB_LABKIT	0x02
USB_16PR	  0x03
USB_14ADDA	0x05
USB_8PR		  0x06
USB_4PR		  0x07
USB_8PI		  0x08
USB_8RO		  0x09
USB_16PI	  0x0A
USB_16RO	  0x0B
USB_32PI	  0x0C
USB_32RO	  0x0D
}

  Is8PR := False;
  IsLABKIT := False;

  Case index of        //Type Define of USB LAB KIT
    0:begin
        IsLABKIT := True;
        Result := 2;
    end;

    1:begin            //Type Define of USB 4 Photo Input / Relay Output Board
        Result := 7;
    end;

    2:begin           //Type Define of USB 8 Photo Input Board
        Result := 8;
    end;

    3:begin           //Type Define of USB 8 Relay Output Board
        Result := 9;
    end;

    4:begin          //Type Define of USB 8 Photo Input / Relay Output Board
        Is8PR := True;
        Result := 6;
    end;

    5:begin          //Type Define of USB 16 Photo Input Board
        Result := 10;
    end;

    6:begin         //Type Define of USB 16 Relay Output Board
        Result := 11;
    end;

    7:begin         //Type Define of USB 16 Photo Input / Relay Output Board
        Result := 3;
    end;

    8:begin        //Type Define of USB 16 Photo Input / Output Board
        Result := 1;
    end;

    9:begin        //Type Define of USB 32 Photo Input Board
        Result := 12;
    end;

    10:begin       //Type Define of USB 32 Relay Output Board
         Result := 13;
    end;

    11:begin       //Type Define of USB AD/DA Board
         Result := 5;
    end;
  end;
end;

procedure TForm1.RadioButton1Click(Sender: TObject);
begin
  Mode := true;
  cbCom.Visible := false;
end;

procedure TForm1.RadioButton2Click(Sender: TObject);
begin
  Mode := false;
  cbCom.Visible := true;
end;

procedure TForm1.Timer1Timer(Sender: TObject);
var
 temp : byte;
begin
  // keep polling to build serial communication

  com_GetDigitalByte(hDevice,0,@temp);
end;

end.
